package Masterkey::Admin::Test;
use Masterkey::Admin::Test::USI;
use Masterkey::Admin::Test::NonUSI;

# Objects for testing target functionality

use strict;
use warnings;

use HTML::Entities;
use ZOOM;


sub new {
    my $class = shift();
    my($admin, $usiParam, $record) = @_;

    if ($usiParam || $admin->conf("usiBaseUrl")) {
	return new Masterkey::Admin::Test::USI(@_);
    } else {
	return new Masterkey::Admin::Test::NonUSI(@_);
    }
}


sub admin { shift()->{"admin"} }
sub usiParam { shift()->{"usiParam"} }
sub record { shift()->{"record"} }


1;
